/*
 * Copyright (c) 2013-2023 NIBIO.
 *
 * This file is part of VIPSWeb 
 * (see https://gitlab.nibio.no/VIPS/VIPSWeb).
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 */

/**
 * Generic map for selecting a weather station
 * @copyright 2015 <a href="http://www.nibio.no/">NIBIO</a>
 * @author Tor-Einar Skog <tor-einar.skog@nibio.no>
 */
var map;

/*
 * KML layer map with weather station information
 * @author Tor-Einar Skog <tor-einar.skog@nibio.no>
 */

/**
 * 
 * @param {ol.Coordinate} center - coordinates for the map's center (WGS84)
 * @param {int} zoomLevel - the zoom level (1-15, 1 is world wide view, 15 is greatest zoom)
 * @param {int} organizationId - which organization to show maps from
 * @returns {void}
 */
function initMap(center, zoomLevel, attribution, organizationId, weatherStationFormSelectId)
{
    // Background layer is OpenStreetMap
    var backgroundLayer = new ol.layer.Tile({
                    source: new ol.source.OSM({
                        attributions: [
                            new ol.Attribution({
                              html: attribution
                            })
                          ]
                    })
    });
    
    // The weather station layer
    var weatherStationLayer = new ol.layer.Vector({
    source: new ol.source.Vector({
        url: settings.vipslogicProtocol + "://" + settings.vipslogicServerName +"/rest/weatherstations/kml/" + organizationId,
        format: new ol.format.KML(),
        projection: ol.proj.get("EPSG:3857")
      })
    });
    
    // Layer for popup
    var popOverlay = new ol.Overlay({
      element: document.getElementById("popover")
    });
    
    // Creating the map
    map = new ol.Map({
                    target: 'weatherStationSelectionMap',
                    layers: [backgroundLayer,weatherStationLayer],
                    overlays: [popOverlay],
                    renderer: 'canvas'
    });
    
    var centerPosition = ol.proj.transform(center, 'EPSG:4326', map.getView().getProjection().getCode());

    // Setting zoom and center for the map (need to do this after creating map. so that we kan transform our
    // center to correct map projection)
    var view = new ol.View({
            center: centerPosition,
            zoom:zoomLevel
    });
    map.setView(view);
    
    // Using Bootstrap's popover plugin. See http://getbootstrap.com/javascript/#popovers
    var poiDetails = $("#popover");
    
    
    
    // Displays popup with forecasts for a given station
    // (if there is a station where the click event is fired)
    var displayFeatureDetails = function(pixel, coordinate) {
          var feature = map.forEachFeatureAtPixel(pixel, function(feature,layer){
             return feature; 
          });

          if (feature) {
              // Position the popup, and hiding it
              // Resetting information from (possible) former popups
              var geometry = feature.getGeometry();
              popOverlay.setPosition(geometry.getCoordinates());
              poiDetails.popover('destroy');
              // Create the popup, showing it
            poiDetails.popover({
                    animation: true,
                    trigger: 'manual',
                    html: true,
                    placement: "auto top",
                    title: feature.get("name") + (feature.get("infoUri") != undefined ? 
              				" <a href='" + feature.get("infoUri") + "' target='new'><span class='fa fa-external-link'></span></a>"
              				:"")
              				+ "<button type='button' id='close' class='close' onclick='$(\"#popover\").popover(\"hide\");'>&times;</button>"
              				,
                    content: "<button type='button' class='btn btn-primary' onclick='selectWeatherStation(\"" + weatherStationFormSelectId + "\"," + feature.getId() +")'>" + gettext("Select station") + "</button>"
            });

            poiDetails.popover('show');


          } else {
        	  //console.log("No feature, sorry");
              poiDetails.popover('destroy');
          }

    };
    

    // On click, display forecasts in popup
    map.on('singleclick', function(evt) {
            var pixel = map.getEventPixel(evt.originalEvent);
              displayFeatureDetails(pixel);
            });
}

function selectWeatherStation(weatherStationFormSelectId, weatherStationId)
{
	var selectList = document.getElementById(weatherStationFormSelectId);
	for(i=0; i<selectList.options.length; i++)
	{
		var option = selectList.options[i];
		option.selected = option.value == weatherStationId;
	}
}
